<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-Unix-blue.svg?longCache=True)]()

#### Installation
```bash
$ [sudo] pip install pid-elapsed
```

#### Scripts usage
command|`usage`
-|-
`pid-elapsed` |`usage: pid-elapsed [format] pid`

#### Examples
```bash
$ pid-elapsed <pid>             # --seconds
3601
$ pid-elapsed --minutes <pid>   # --minutes
60
$ pid-elapsed --hours <pid>     # --hours
1
$ pid-elapsed --days <pid>      # --days
0
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>